==> haskell-postgresql-binary-0.12.4.1-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-binary
version:              0.12.4.1
visibility:           public
id:                   postgresql-binary-0.12.4.1-3rb0hAFNFxuyaF3XjmX7u
key:                  postgresql-binary-0.12.4.1-3rb0hAFNFxuyaF3XjmX7u
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/postgresql-binary 
synopsis:             Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.

    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql hasql>
    is based on this library.

    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.

category:             PostgreSQL, Database, Codecs, Parsing
abi:                  59db68cc9c1d80b968a6086ed92e7afb
exposed:              True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding

hidden-modules:
    PostgreSQL.Binary.Encoding.Builders PostgreSQL.Binary.Prelude
    PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
    PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
    PostgreSQL.Binary.Inet PostgreSQL.Binary.BuilderPrim

import-dirs:          /usr/lib/ghc-9.0.2/site-local/postgresql-binary-0.12.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/postgresql-binary-0.12.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-binary
hs-libraries:         HSpostgresql-binary-0.12.4.1-3rb0hAFNFxuyaF3XjmX7u
depends:
    aeson-1.5.6.0-CXf7LknqfgZ2Hfi5jmQpYM base-4.15.1.0
    binary-parser-0.5.7.2-IkiZLcCCpGFLj7y6MOJE89 bytestring-0.10.12.1
    bytestring-strict-builder-0.4.5.5-BEYpN8TWekHLHyO45r2v2v
    containers-0.6.4.1 network-ip-0.3.0.3-DyYvna3BLKv9av73Dzc3ne
    scientific-0.3.7.0-8SzWenanV6tE1tEz514SLi text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-LWNw197ajNNFytwMBd2fIa
    uuid-1.3.15-2POBWCUdfBwABo9T0qaYlc
    vector-0.12.3.1-50x5zOQFZ1CIL15Y9vpvyM

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.4.1-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-binary
version:              0.12.4.1
visibility:           public
id:                   postgresql-binary-0.12.4.1-EDBDr7gFspEGL13Bgq5e1j
key:                  postgresql-binary-0.12.4.1-EDBDr7gFspEGL13Bgq5e1j
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/postgresql-binary 
synopsis:             Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.

    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql hasql>
    is based on this library.

    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.

category:             PostgreSQL, Database, Codecs, Parsing
abi:                  26bf9151a8c4ef271374a8e04f152a1d
exposed:              True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding

hidden-modules:
    PostgreSQL.Binary.Encoding.Builders PostgreSQL.Binary.Prelude
    PostgreSQL.Binary.Integral PostgreSQL.Binary.Interval
    PostgreSQL.Binary.Numeric PostgreSQL.Binary.Time
    PostgreSQL.Binary.Inet PostgreSQL.Binary.BuilderPrim

import-dirs:          /usr/lib/ghc-9.0.2/site-local/postgresql-binary-0.12.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/postgresql-binary-0.12.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-binary
hs-libraries:         HSpostgresql-binary-0.12.4.1-EDBDr7gFspEGL13Bgq5e1j
depends:
    aeson-1.5.6.0-2qjjmnAKexuB7sng1Bw4lo base-4.15.1.0
    binary-parser-0.5.7.2-D92vYoY0frN8MDtgrb2SyR bytestring-0.10.12.1
    bytestring-strict-builder-0.4.5.6-4cwdsRMjYMgJTcrp25ynFH
    containers-0.6.4.1 network-ip-0.3.0.3-6dsxyEiwD5b59C9uW8F65p
    scientific-0.3.7.0-FYeHmde7xzlEgYl8NcWZ19 text-1.2.5.0 time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-FiUFtsHtx28IfDtF4iaH6c
    uuid-1.3.15-4L4cmKWKv01JX4iNxh41pc
    vector-0.12.3.1-IW8bpHdTmVFCpd7YXsgtBR

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
